<?php

require_once "phpfspot_cfg.php";
require_once "phpfspot_db.php";
require_once "phpfspot_tmpl.php";

class PHPFSPOT {

   var $cfg;
   var $db;
   var $tmpl;
   var $tags;
   var $avail_tags;
   var $photos;
   var $avail_photos;
   var $current_photo;
   var $current_tags;

   public function __construct()
   {
      $this->cfg = new PHPFSPOT_CFG;

      $this->db = new PHPFSPOT_DB(&$this, $this->cfg->db);
      $this->tmpl = new PHPFSPOT_TMPL($this);

      $this->get_tags();
      $this->get_photos();

      if(isset($_GET['id']) && is_numeric($_GET['id']))
         $this->current_photo = $_GET['id'];

   } // __construct()

   public function __destruct()
   {

   } // __destruct()

   public function show()
   {

      $this->prepare_single_photo($this->current_photo);
      $this->tmpl->assign('tags', $this->tags);
      $this->tmpl->show("index.tpl");


   } // show()

   private function get_tags()
   {
      $this->avail_tags = Array();
      $count = 0;
   
      $result = $this->db->db_query("
         SELECT id,name
         FROM tags
         ORDER BY sort_priority ASC
      ");
      
      while($row = $this->db->db_fetch_object($result)) {

         $tag_id = $row['id'];
         $tag_name = $row['name'];

         $this->tags[$tag_id] = $tag_name; 
         $this->avail_tags[$count] = $tag_id;

         $count++;

      }

   } // get_tags()

   private function get_photos()
   {
      $this->avail_photos = Array();
      $count = 0;

      $result = $this->db->db_query("
         SELECT id, name
         FROM photos
         ORDER BY time ASC
      ");
      
      while($row = $this->db->db_fetch_object($result)) {

         $photo_id = $row['id'];
         $photo_name = $row['name'];

         $this->photos[$photo_id] = $photo_name;
         $this->avail_photos[$count] = $photo_id;

         if(!isset($this->current_photo))
            $this->current_photo = $count;

         $count++;

      }

   } // get_photos()

   public function get_photo_details($idx)
   {
      $result = $this->db->db_query("
         SELECT *
         FROM photos
         WHERE id='". $idx ."'
      ");
      
      return $this->db->db_fetch_object($result);

   } // get_photo_details

   public function translate_path($path, $width = 0)
   {  
      return str_replace($this->cfg->path_replace_from, $this->cfg->path_replace_to, $path);

   } // translate_path

   public function prepare_single_photo($photo)
   {
      if(isset($photo)) {
         $this->tmpl->assign('image_url', 'phpfspot_img.php?idx='. $this->avail_photos[$photo] ."&amp;width=". $this->cfg->photo_width);
      }

      if($photo > 0) {
         $this->tmpl->assign('previous_url', "javascript:showImage(". ($photo-1) .");");
      }

      if($photo < count($this->avail_photos)) {
         $this->tmpl->assign('next_url', "javascript:showImage(". ($photo+1) .");");
      }

   } // prepare_single_photo()

   public function getAvailableTags()
   {
      foreach($this->avail_tags as $tag)
      {
         if(isset($_SESSION['selected_tags']) && in_array($tag, $_SESSION['selected_tags']))
            continue;

         // return all available (= not selected) tags
         print "<a href=\"javascript:Tags('add', ". $tag .");\">". $this->tags[$tag] ."</a>&nbsp;";

      }

   } // getAvailableTags()

   public function getSelectedTags()
   {
      foreach($this->avail_tags as $tag)
      {
         // return all selected tags
         if(isset($_SESSION['selected_tags']) && in_array($tag, $_SESSION['selected_tags'])) {
            print "<a href=\"javascript:Tags('del', ". $tag .");\">". $this->tags[$tag] ."</a>&nbsp;";
         }

      }

      print "<a href=\"javascript:Tags('reset', 0);\">Reset Tags</a>";

   } // getSelectedTags()

   public function addTag($tag)
   {
      if(!isset($_SESSION['selected_tags']))
         $_SESSION['selected_tags'] = Array();

      array_push($_SESSION['selected_tags'], $tag);
   
   } // addTag()

   public function delTag($tag)
   {
      if(isset($_SESSION['selected_tags'])) {
         $key = array_search($tag, $_SESSION['selected_tags']);
         unset($_SESSION['selected_tags'][$key]);
      }

   } // delTag()

   public function resetTags()
   {
      unset($_SESSION['selected_tags']);

   } // resetTags()

   public function showPhotoIndex()
   {

      foreach($this->avail_photos as $photo)
      {
         print "<img src=\"phpfspot_img.php?idx=". $photo ."&amp;width=". $this->cfg->thumb_width ."\" /><br />\n";
      }

   } // showPhotoIndex()

}

?>
